@@ -23,10 +23,12 @@ from Products.MailHost.interfaces import IMailHost
 from zope.component import getSiteManager
 from zope.component import getUtility
 from zope.component.hooks import setSite
+from zope.dottedname.resolve import resolve
 from zope.event import notify
 from zope.traversing.interfaces import BeforeTraverseEvent
 
 import six
+import transaction
 
 
 class PloneFixture(Layer):
@@ -53,7 +55,8 @@ class PloneFixture(Layer):
         ('Products.PluggableAuthService', {'loadZCML': True}, ),
         ('Products.PluginRegistry', {'loadZCML': True}, ),
         ('Products.PlonePAS', {'loadZCML': True}, ),
-        ('Products.CMFFormController', {'loadZCML': True}, ),
+        # product for Plone 5.2 only, be silent when not available on Plone 6:
+        ('Products.CMFFormController', {'loadZCML': True, 'silent': True}, ),
         ('Products.CMFDynamicViewFTI', {'loadZCML': True}, ),
         ('Products.CMFPlacefulWorkflow', {'loadZCML': True}, ),
         ('Products.MimetypesRegistry', {'loadZCML': True}, ),
@@ -104,6 +107,9 @@ class PloneFixture(Layer):
         with zope.zopeApp() as app:
             self.setUpProducts(app)
             self.setUpDefaultContent(app)
+            # If there is no savepoint most tests fail with a PosKeyError
+            # See https://github.com/plone/Products.CMFPlone/issues/3467
+            transaction.savepoint(optimistic=True)
 
     def tearDown(self):
 
@@ -145,8 +151,6 @@ class PloneFixture(Layer):
         # Load dependent products's ZCML - Plone doesn't specify dependencies
         # on Products.* packages fully
 
-        from zope.dottedname.resolve import resolve
-
         def loadAll(filename):
             for p, config in self.products:
                 if not config['loadZCML']:
@@ -181,6 +185,12 @@ class PloneFixture(Layer):
 
         for p, config in self.products:
             if config.get('install', True):
+                if config.get('silent'):
+                    # When product is not available, do not complain or warn.
+                    try:
+                        resolve(p)
+                    except ImportError:
+                        continue
                 zope.installProduct(app, p)
 
     def tearDownProducts(self, app):
